import { ɵɵdefineInjectable, Injectable, Component, Input, NgModule } from '@angular/core';
import { Store } from 'projects/angular-pivot-table/src/lib/store/store';
import { CommonModule } from '@angular/common';

class AngularPivotTableService {
    constructor() { }
}
AngularPivotTableService.ɵprov = ɵɵdefineInjectable({ factory: function AngularPivotTableService_Factory() { return new AngularPivotTableService(); }, token: AngularPivotTableService, providedIn: "root" });
AngularPivotTableService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
AngularPivotTableService.ctorParameters = () => [];

class AngularPivotTableComponent {
    constructor() {
        this.source = [];
        this.default_configs = {
            rows: '',
            columns: '',
            css: {
                row_selection_class: 'selected',
                header_class: '',
                table_class: ''
            },
            data_loading_text: 'Loading...',
            row_class_function: () => true,
            row_select_function: () => true
        };
        this.store = new Store();
        this.processed_data = [];
        this.processed_headers = [];
    }
    ngOnInit() {
        this.validateConfigs();
        this.setDefaultConfigs();
    }
    ngOnChanges() {
        this.validateConfigs();
        this.setDefaultConfigs();
        this.store.processData(this.source, this.configs);
        this.processed_data = this.store.getProcessedData();
        this.processed_headers = this.store.getProcessedHeaders();
    }
    validateConfigs() {
        if (!this.source) {
            window.console.warn('source can\'t be empty!');
            return;
        }
        if (!this.configs) {
            window.console.warn('configs can\'t be empty!');
            return;
        }
    }
    setDefaultConfigs() {
        this.configs = Object.assign({}, this.default_configs, this.configs);
        // Deep clone.
        this.configs.css = Object.assign({}, this.default_configs.css, this.configs.css);
    }
}
AngularPivotTableComponent.decorators = [
    { type: Component, args: [{
                selector: 'db-angular-pivot-table',
                template: "<table [attr.class]=\"'db-table-view' + configs.css.table_class\">\r\n    <thead>\r\n        <tr>\r\n            <th class=\"header-corner\">\r\n                <table class=\"header-corner\">\r\n                    <tr>\r\n                        <td class=\"corner-top\">{{configs.columns}}</td>\r\n                    </tr>\r\n                    <tr>\r\n                        <td class=\"corner-bottom\">{{configs.rows}}</td>\r\n                    </tr>\r\n                </table>\r\n            </th>\r\n            <th *ngFor=\"let header of processed_headers\">\r\n                {{header}}\r\n            </th>\r\n            <th>\r\n                Total\r\n            </th>\r\n        </tr>\r\n    </thead>\r\n\r\n    <tbody>\r\n        <tr *ngFor=\"let row of processed_data\">\r\n            <td *ngFor=\"let col of row\">\r\n                {{col}}\r\n            </td>\r\n        </tr>\r\n    </tbody>\r\n</table>",
                styles: [".db-table-view{border:1px solid grey;border-collapse:collapse;border-spacing:0;color:#4b4b4b;display:table;line-height:1.5em;max-width:100%;overflow:auto;word-break:normal;word-break:keep-all}.db-table-view table.header-corner{border-collapse:collapse;width:100%}.db-table-view table.header-corner td{font-weight:400}.db-table-view table.header-corner td.corner-top{border-width:0 0 1px}.db-table-view table.header-corner td.corner-bottom{border-width:0}.db-table-view tbody tr td:first-child{font-weight:600}.db-table-view tr.selected{background-color:#e2e7eb}.db-table-view tr th{border:1px solid #cdd5dc;box-sizing:border-box;color:#181818;font-size:1rem;font-weight:600;line-height:1.25;padding:.5rem;position:relative;vertical-align:middle}.db-table-view tr th.header-corner{padding:0}.db-table-view tr td{border:1px solid #cdd5dc;box-sizing:border-box;padding:.5rem;position:relative;vertical-align:middle}"]
            },] }
];
AngularPivotTableComponent.ctorParameters = () => [];
AngularPivotTableComponent.propDecorators = {
    source: [{ type: Input }],
    configs: [{ type: Input }]
};

class AngularPivotTableModule {
}
AngularPivotTableModule.decorators = [
    { type: NgModule, args: [{
                declarations: [AngularPivotTableComponent],
                imports: [
                    CommonModule
                ],
                exports: [AngularPivotTableComponent]
            },] }
];

/*
 * Public API Surface of angular-pivot-table
 */

/**
 * Generated bundle index. Do not edit.
 */

export { AngularPivotTableComponent, AngularPivotTableModule, AngularPivotTableService };
//# sourceMappingURL=angular-pivot-table.js.map
